@@ -4,15 +4,18 @@ from prompt_toolkit import prompt
 from prompt_toolkit.formatted_text import HTML
 
 
-def prompt_continuation(width, line_number, is_soft_wrap):
+def prompt_continuation(width, line_number, wrap_count):
     """
     The continuation: display line numbers and '->' before soft wraps.
 
     Notice that we can return any kind of formatted text from here.
+
+    The prompt continuation doesn't have to be the same width as the prompt
+    which is displayed before the first line, but in this example we choose to
+    align them. The `width` input that we receive here represents the width of
+    the prompt.
     """
-    # (make sure that the width of the continuation does not exceed the given
-    # width. -- It is the prompt that determines the width of the left margin.)
-    if is_soft_wrap:
+    if wrap_count > 0:
         return ' ' * (width - 3) + '-> '
     else:
         text = ('- %i - ' % (line_number + 1)).rjust(width)
